%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do not modify this file since it was automatically generated from:
% 
%  Verbose.R
% 
% by the Rdoc compiler part of the R.oo package.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{writeRaw.Verbose}
\alias{writeRaw.Verbose}
\alias{Verbose.writeRaw}
\alias{writeRaw,Verbose-method}

\title{Writes objects if above threshold}

\description{
  Writes objects if above threshold.
  This method is used by all other methods of this class for output.
}

\usage{
\method{writeRaw}{Verbose}(this, ..., sep="", level=this$defaultLevel)
}

\arguments{
 \item{...}{Objects to be passed to \code{\link[base]{paste}}().}
 \item{sep}{The default separator \code{\link[base]{character}} string.}
 \item{level}{A \code{\link[base]{numeric}} value to be compared to the threshold.}
}

\value{
  Returns nothing.
}

\author{Henrik Bengtsson}

\seealso{
  For more information see \code{\link{Verbose}}.
}


\keyword{internal}
\keyword{methods}
\keyword{programming}
