%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do not modify this file since it was automatically generated from:
% 
%  Options.R
% 
% by the Rdoc compiler part of the R.oo package.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{nbrOfOptions.Options}
\alias{nbrOfOptions.Options}
\alias{Options.nbrOfOptions}
\alias{nbrOfOptions,Options-method}

\title{Gets the number of options set}

\description{
 Gets the number of options set.
}

\usage{
\method{nbrOfOptions}{Options}(this, ...)
}

\arguments{
  \item{...}{Not used.}
}

\value{Returns an \code{\link[base]{integer}}.}

\author{Henrik Bengtsson}

\seealso{
  For more information see \code{\link{Options}}.
}


\keyword{internal}
\keyword{methods}
\keyword{programming}
