%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do not modify this file since it was automatically generated from:
% 
%  isPackageInstalled.R
% 
% by the Rdoc compiler part of the R.oo package.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{isPackageInstalled}
\alias{isPackageInstalled.default}
\alias{isPackageInstalled}

\title{Checks if a package is installed or not}

\description{
  Checks if a package is installed or not.
}

\usage{
\method{isPackageInstalled}{default}(package, ...)
}

\arguments{
 \item{package}{A \code{\link[base]{character}} \code{\link[base]{vector}} of package names.}
 \item{...}{Not used.}
}

\value{
  Returns a \code{\link[base]{logical}} \code{\link[base]{vector}}.
}

\author{Henrik Bengtsson}

\seealso{
  \code{\link{isPackageLoaded}}().
}



\keyword{utilities}
\keyword{package}
