%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do not modify this file since it was automatically generated from:
% 
%  Verbose.R
% 
% by the Rdoc compiler part of the R.oo package.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{timestamp.Verbose}
\alias{timestamp.Verbose}
\alias{Verbose.timestamp}
\alias{timestamp,Verbose-method}

\title{Writes a timestamp}

\description{
  Writes a timestamp with default format [2005-06-23 21:20:03].
}

\usage{
\method{timestamp}{Verbose}(this, format=getTimestampFormat(this), ...)
}

\arguments{
 \item{stamp}{A timestamp \code{\link[base]{character}} to be written.}
 \item{...}{Not used.}
}

\value{
  Returns nothing.
}

\author{Henrik Bengtsson}

\seealso{
  For more information see \code{\link{Verbose}}.
}


\keyword{internal}
\keyword{methods}
\keyword{programming}
