%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do not modify this file since it was automatically generated from:
% 
%  NullVerbose.R
% 
% by the Rdoc compiler part of the R.oo package.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{isOn.NullVerbose}
\alias{isOn.NullVerbose}
\alias{NullVerbose.isOn}
\alias{isOn,NullVerbose-method}

\title{Checks if the output is on}

\description{
  Checks if the output is on.
}

\usage{
\method{isOn}{NullVerbose}(this, ...)
}

\arguments{
 \item{...}{Not used.}
}

\value{
  Returns always \code{\link[base:logical]{FALSE}}.
}

\author{Henrik Bengtsson}

\seealso{
  For more information see \code{\link{NullVerbose}}.
}


\keyword{internal}
\keyword{methods}
\keyword{programming}
