%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Do not modify this file since it was automatically generated from:
% 
%  ProgressBar.R
% 
% by the Rdoc compiler part of the R.oo package.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\name{update.ProgressBar}
\alias{update.ProgressBar}
\alias{ProgressBar.update}
\alias{update,ProgressBar-method}

\title{Updates progress bar}

\description{
  Updates progress bar.
}

\usage{
\method{update}{ProgressBar}(object, visual=TRUE, ...)
}

\arguments{
 \item{visual}{If \code{\link[base:logical]{TRUE}}, the progress bar is redrawn, otherwise not.}
 \item{...}{Not used.}
}

\value{
  Returns nothing.
}

\author{Henrik Bengtsson}

\seealso{
  For more information see \code{\link{ProgressBar}}.
}
\keyword{internal}
\keyword{methods}
